@@ -1,8 +1,7 @@
 /* SPDX-License-Identifier: LGPL-2.1+ */
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE 1
-#endif
+#include "config.h"
+
 #include <errno.h>
 #include <fcntl.h>
 #include <grp.h>
@@ -22,7 +21,8 @@
 
 #include "compiler.h"
 #include "conf.h"
-#include "config.h"
+#include "hlist.h"
+#include "idmap_utils.h"
 #include "list.h"
 #include "log.h"
 #include "macro.h"
@@ -33,6 +33,9 @@
 #include "utils.h"
 
 __hidden extern int lxc_log_fd;
+/* Assume we want to become root */
+static uid_t uid = 0;
+static gid_t gid = 0;
 
 static void usage(const char *name)
 {
@@ -91,8 +94,7 @@ static int do_child(void *vargv)
 	if (!lxc_drop_groups() && errno != EPERM)
 		return -1;
 
-	/* Assume we want to become root */
-	if (!lxc_switch_uid_gid(0, 0))
+	if (!lxc_switch_uid_gid(uid, gid))
 		return -1;
 
 	ret = unshare(CLONE_NEWNS);
@@ -114,14 +116,13 @@ static int do_child(void *vargv)
 	return -1;
 }
 
-static struct lxc_list active_map;
+static LIST_HEAD(active_map);
 
 static int add_map_entry(long host_id, long ns_id, long range, int which)
 {
-	struct lxc_list *tmp = NULL;
 	struct id_map *newmap;
 
-	newmap = malloc(sizeof(*newmap));
+	newmap = zalloc(sizeof(*newmap));
 	if (!newmap)
 		return -1;
 
@@ -129,14 +130,8 @@ static int add_map_entry(long host_id, long ns_id, long range, int which)
 	newmap->nsid = ns_id;
 	newmap->range = range;
 	newmap->idtype = which;
-	tmp = malloc(sizeof(*tmp));
-	if (!tmp) {
-		free(newmap);
-		return -1;
-	}
 
-	tmp->elem = newmap;
-	lxc_list_add_tail(&active_map, tmp);
+	list_add_tail(&newmap->head, &active_map);
 	return 0;
 }
 
@@ -234,13 +229,13 @@ static int read_default_map(char *fnam, int which, char *user)
 static int find_default_map(void)
 {
 	__do_free char *buf = NULL;
-	size_t bufsize;
+	ssize_t bufsize;
 	struct passwd pwent;
 	int ret = -1;
 	struct passwd *pwentp = NULL;
 
 	bufsize = sysconf(_SC_GETPW_R_SIZE_MAX);
-	if (bufsize == -1)
+	if (bufsize < 0)
 		bufsize = 1024;
 
 	buf = malloc(bufsize);
@@ -267,12 +262,14 @@ static int find_default_map(void)
 	return 0;
 }
 
-static bool is_in_ns_range(long id, struct id_map *map)
+static bool is_in_ns_range(unsigned long id, struct id_map *map)
 {
 	if (id < map->nsid)
 		return false;
+
 	if (id >= map->nsid + map->range)
 		return false;
+
 	return true;
 }
 
@@ -280,11 +277,9 @@ static bool do_map_self(void)
 {
 	struct id_map *map;
 	long nsuid = 0, nsgid = 0;
-	struct lxc_list *tmp = NULL;
 	int ret;
 
-	lxc_list_for_each(tmp, &active_map) {
-		map = tmp->elem;
+	list_for_each_entry(map, &active_map, head) {
 		if (map->idtype == ID_TYPE_UID) {
 			if (is_in_ns_range(nsuid, map))
 				nsuid += map->range;
@@ -336,9 +331,7 @@ int main(int argc, char *argv[])
 		}
 	}
 
-	lxc_list_init(&active_map);
-
-	while ((c = getopt(argc, argv, "m:hs")) != EOF) {
+	while ((c = getopt(argc, argv, "m:hsu:g:")) != EOF) {
 		switch (c) {
 		case 'm':
 			ret = parse_map(optarg);
@@ -353,13 +346,21 @@ int main(int argc, char *argv[])
 		case 's':
 			map_self = true;
 			break;
+		case 'u':
+			if (lxc_safe_uint(optarg, &uid) < 0)
+				return -1;
+			break;
+		case 'g':
+			if (lxc_safe_uint(optarg, &gid) < 0)
+				return -1;
+			break;
 		default:
 			usage(argv[0]);
 			_exit(EXIT_FAILURE);
 		}
 	};
 
-	if (lxc_list_empty(&active_map)) {
+	if (list_empty(&active_map)) {
 		ret = find_default_map();
 		if (ret < 0) {
 			fprintf(stderr, "Failed to find subuid or subgid allocation\n");
