@@ -3,14 +3,17 @@
 #ifndef __LXC_COMMANDS_H
 #define __LXC_COMMANDS_H
 
+#include "config.h"
+
 #include <errno.h>
 #include <stdio.h>
 #include <sys/types.h>
 #include <unistd.h>
 
+#include "lxc.h"
+
 #include "compiler.h"
 #include "cgroups/cgroup.h"
-#include "lxccontainer.h"
 #include "macro.h"
 #include "state.h"
 
@@ -49,6 +52,7 @@ typedef enum {
 	LXC_CMD_GET_CGROUP_CTX			= 23,
 	LXC_CMD_GET_CGROUP_FD			= 24,
 	LXC_CMD_GET_LIMIT_CGROUP_FD		= 25,
+	LXC_CMD_GET_SYSTEMD_SCOPE		= 26,
 	LXC_CMD_MAX,
 } lxc_cmd_t;
 
@@ -112,9 +116,10 @@ __hidden extern char *lxc_cmd_get_config_item(const char *name, const char *item
 					      const char *lxcpath);
 __hidden extern char *lxc_cmd_get_name(const char *hashed_sock);
 __hidden extern char *lxc_cmd_get_lxcpath(const char *hashed_sock);
+__hidden extern char *lxc_cmd_get_systemd_scope(const char *name, const char *lxcpath);
 __hidden extern pid_t lxc_cmd_get_init_pid(const char *name, const char *lxcpath);
 __hidden extern int lxc_cmd_get_init_pidfd(const char *name, const char *lxcpath);
-__hidden extern int lxc_cmd_get_state(const char *name, const char *lxcpath);
+__hidden extern int lxc_cmd_get_state(const char *name, const char *lxcpath, int timeout);
 __hidden extern int lxc_cmd_stop(const char *name, const char *lxcpath);
 
 /* lxc_cmd_add_state_client    Register a new state client fd in the container's
@@ -137,11 +142,11 @@ __hidden __access_r_nosize(3) extern int lxc_cmd_add_state_client(const char *na
 __hidden extern int lxc_cmd_serve_state_clients(const char *name, const char *lxcpath,
 						lxc_state_t state);
 
-struct lxc_epoll_descr;
+struct lxc_async_descr;
 struct lxc_handler;
 
 __hidden extern int lxc_server_init(const char *name, const char *lxcpath, const char *suffix);
-__hidden extern int lxc_cmd_mainloop_add(const char *name, struct lxc_epoll_descr *descr,
+__hidden extern int lxc_cmd_mainloop_add(const char *name, struct lxc_async_descr *descr,
 					 struct lxc_handler *handler);
 __hidden extern int lxc_try_cmd(const char *name, const char *lxcpath);
 __hidden extern int lxc_cmd_console_log(const char *name, const char *lxcpath,
