@@ -1,9 +1,7 @@
 /* SPDX-License-Identifier: LGPL-2.1+ */
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE 1
-#endif
-#define __STDC_FORMAT_MACROS /* Required for PRIu64 to work. */
+#include "config.h"
+
 #include <errno.h>
 #include <fcntl.h>
 #include <inttypes.h>
@@ -18,16 +16,16 @@
 #include <syslog.h>
 #include <unistd.h>
 
+#include "lxc.h"
+
 #include "caps.h"
-#include "config.h"
 #include "file_utils.h"
 #include "log.h"
-#include "lxccontainer.h"
 #include "memory_utils.h"
 #include "utils.h"
 
-#ifndef HAVE_STRLCPY
-#include "include/strlcpy.h"
+#if !HAVE_STRLCPY
+#include "strlcpy.h"
 #endif
 
 #if HAVE_DLOG
@@ -306,9 +304,9 @@ static int lxc_unix_epoch_to_utc(char *buf, size_t bufsize, const struct timespe
  * all fiddle with global variables and locking in various libcs. They cause
  * deadlocks when liblxc is used multi-threaded and no matter how smart you
  * think you are, you __will__ cause trouble using them.
- * (As a short example how this can cause trouble: LXD uses forkstart to fork
+ * (As a short example how this can cause trouble: Incus uses forkstart to fork
  * off a new process that runs the container. At the same time the go runtime
- * LXD relies on does its own multi-threading thing which we can't control. The
+ * Incus relies on does its own multi-threading thing which we can't control. The
  * fork()ing + threading then seems to mess with the locking states in these
  * time functions causing deadlocks.)
  * The current solution is to be good old unix people and use the Epoch as our
