@@ -1125,6 +1125,11 @@ static int do_start(void *data)
 		if (!lxc_switch_uid_gid(nsuid, nsgid))
 			goto out_warn_father;
 
+		ret = prctl(PR_SET_DUMPABLE, prctl_arg(1), prctl_arg(0),
+			    prctl_arg(0), prctl_arg(0));
+		if (ret < 0)
+			goto out_warn_father;
+
 		/* set{g,u}id() clears deathsignal */
 		ret = lxc_set_death_signal(SIGKILL, handler->monitor_pid, status_fd);
 		if (ret < 0) {
@@ -1367,7 +1372,7 @@ static int do_start(void *data)
 	}
 
 	if (handler->conf->ttys.tty_names) {
-		ret = putenv(handler->conf->ttys.tty_names);
+		ret = setenv("container_ttys", handler->conf->ttys.tty_names, 1);
 		if (ret < 0) {
 			SYSERROR("Failed to set environment variable for container ptys");
 			goto out_warn_father;
