@@ -1,8 +1,7 @@
 /* SPDX-License-Identifier: LGPL-2.1+ */
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE 1
-#endif
+#include "config.h"
+
 #include <ctype.h>
 #include <dirent.h>
 #include <errno.h>
@@ -21,7 +20,6 @@
 #include <sys/wait.h>
 #include <unistd.h>
 
-#include "config.h"
 #include "log.h"
 #include "nbd.h"
 #include "parse.h"
@@ -30,8 +28,8 @@
 #include "syscall_wrappers.h"
 #include "utils.h"
 
-#ifndef HAVE_STRLCPY
-#include "include/strlcpy.h"
+#if !HAVE_STRLCPY
+#include "strlcpy.h"
 #endif
 
 #ifndef BLKGETSIZE64
@@ -184,6 +182,8 @@ int detect_fs(struct lxc_storage *bdev, char *type, int len)
 		_exit(EXIT_FAILURE);
 
 	while (getline(&line, &linelen, f) != -1) {
+		ssize_t nbytes;
+
 		sp1 = strchr(line, ' ');
 		if (!sp1)
 			_exit(EXIT_FAILURE);
@@ -203,7 +203,8 @@ int detect_fs(struct lxc_storage *bdev, char *type, int len)
 		*sp3 = '\0';
 
 		sp2++;
-		if (write(p[1], sp2, strlen(sp2)) != strlen(sp2))
+		nbytes = write(p[1], sp2, strlen(sp2));
+		if (nbytes < 0 || (size_t)nbytes != strlen(sp2))
 			_exit(EXIT_FAILURE);
 
 		_exit(EXIT_SUCCESS);
@@ -327,7 +328,7 @@ int find_fstype_cb(char *buffer, void *data)
 	DEBUG("Trying to mount \"%s\"->\"%s\" with FSType \"%s\"", cbarg->rootfs,
 	      cbarg->target, fstype);
 
-	if (parse_mntopts(cbarg->options, &mntflags, &mntdata) < 0) {
+	if (parse_mntopts_legacy(cbarg->options, &mntflags, &mntdata) < 0) {
 		free(mntdata);
 		return 0;
 	}
@@ -407,41 +408,7 @@ bool unpriv_snap_allowed(struct lxc_storage *b, const char *t, bool snap,
 	return false;
 }
 
-uint64_t get_fssize(char *s)
-{
-	uint64_t ret;
-	char *end;
-
-	ret = strtoull(s, &end, 0);
-	if (end == s) {
-		ERROR("Invalid blockdev size '%s', using default size", s);
-		return 0;
-	}
-
-	while (isblank(*end))
-		end++;
-
-	if (*end == '\0') {
-		ret *= 1024ULL * 1024ULL; /* MB by default */
-	} else if (*end == 'b' || *end == 'B') {
-		ret *= 1ULL;
-	} else if (*end == 'k' || *end == 'K') {
-		ret *= 1024ULL;
-	} else if (*end == 'm' || *end == 'M') {
-		ret *= 1024ULL * 1024ULL;
-	} else if (*end == 'g' || *end == 'G') {
-		ret *= 1024ULL * 1024ULL * 1024ULL;
-	} else if (*end == 't' || *end == 'T') {
-		ret *= 1024ULL * 1024ULL * 1024ULL * 1024ULL;
-	} else {
-		ERROR("Invalid blockdev unit size '%c' in '%s', using default size", *end, s);
-		return 0;
-	}
-
-	return ret;
-}
-
-bool is_valid_storage_type(const char *type)
+bool lxc_is_valid_storage_type(const char *type)
 {
 	if (strcmp(type, "dir") == 0 ||
 	    strcmp(type, "btrfs") == 0 ||
@@ -461,7 +428,7 @@ int storage_destroy_wrapper(void *data)
 {
 	struct lxc_conf *conf = data;
 
-	(void)lxc_setgroups(0, NULL);
+	(void)lxc_drop_groups();
 
 	if (setgid(0) < 0) {
 		SYSERROR("Failed to setgid to 0");
