@@ -2,9 +2,8 @@
 #ifndef __LXC_SYSCALL_NUMBERS_H
 #define __LXC_SYSCALL_NUMBERS_H
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE 1
-#endif
+#include "config.h"
+
 #include <asm/unistd.h>
 #include <errno.h>
 #include <linux/keyctl.h>
@@ -51,8 +50,9 @@
 		#if _MIPS_SIM == _MIPS_SIM_ABI64	/* n64 */
 			#define __NR_keyctl 5241
 		#endif
+	#elif defined __loongarch64
+		#define __NR_keyctl 219
 	#else
-		#define -1
 		#warning "__NR_keyctl not defined for your architecture"
 	#endif
 #endif
@@ -88,8 +88,9 @@
 		#if _MIPS_SIM == _MIPS_SIM_ABI64
 			#define __NR_memfd_create 5314
 		#endif
+	#elif defined __loongarch64
+		#define __NR_memfd_create 279
 	#else
-		#define -1
 		#warning "__NR_memfd_create not defined for your architecture"
 	#endif
 #endif
@@ -123,8 +124,9 @@
 		#if _MIPS_SIM == _MIPS_SIM_ABI64	/* n64 */
 			#define __NR_pivot_root 5151
 		#endif
+	#elif defined __loongarch64
+		#define __NR_pivot_root 41
 	#else
-		#define -1
 		#warning "__NR_pivot_root not defined for your architecture"
 	#endif
 #endif
@@ -158,8 +160,9 @@
 		#if _MIPS_SIM == _MIPS_SIM_ABI64	/* n64 */
 			#define __NR_setns 5303
 		#endif
+	#elif defined __loongarch64
+		#define __NR_setns 268
 	#else
-		#define -1
 		#warning "__NR_setns not defined for your architecture"
 	#endif
 #endif
@@ -193,8 +196,9 @@
 		#if _MIPS_SIM == _MIPS_SIM_ABI64	/* n64 */
 			#define __NR_sethostname 5165
 		#endif
+	#elif defined __loongarch64
+		#define __NR_sethostname 161
 	#else
-		#define -1
 		#warning "__NR_sethostname not defined for your architecture"
 	#endif
 #endif
@@ -260,8 +264,9 @@
 		#if _MIPS_SIM == _MIPS_SIM_ABI64	/* n64 */
 			#define __NR_signalfd4 5283
 		#endif
+	#elif defined __loongarch64
+		#define __NR_signalfd4 74
 	#else
-		#define -1
 		#warning "__NR_signalfd4 not defined for your architecture"
 	#endif
 #endif
@@ -295,8 +300,9 @@
 		#if _MIPS_SIM == _MIPS_SIM_ABI64	/* n64 */
 			#define __NR_unshare 5262
 		#endif
+	#elif defined __loongarch64
+		#define __NR_unshare 97
 	#else
-		#define -1
 		#warning "__NR_unshare not defined for your architecture"
 	#endif
 #endif
@@ -330,8 +336,9 @@
 		#if _MIPS_SIM == _MIPS_SIM_ABI64	/* n64 */
 			#define __NR_bpf 5315
 		#endif
+	#elif defined __loongarch64
+		#define __NR_bpf 280
 	#else
-		#define -1
 		#warning "__NR_bpf not defined for your architecture"
 	#endif
 #endif
@@ -365,8 +372,9 @@
 		#if _MIPS_SIM == _MIPS_SIM_ABI64	/* n64 */
 			#define __NR_faccessat 5259
 		#endif
+	#elif defined __loongarch64
+		#define __NR_faccessat 48
 	#else
-		#define -1
 		#warning "__NR_faccessat not defined for your architecture"
 	#endif
 #endif
@@ -420,8 +428,9 @@
 		#if _MIPS_SIM == _MIPS_SIM_ABI64	/* n64 */
 			#define __NR_seccomp 5312
 		#endif
+	#elif defined __loongarch64
+		#define __NR_seccomp 277
 	#else
-		#define -1
 		#warning "__NR_seccomp not defined for your architecture"
 	#endif
 #endif
@@ -455,8 +464,9 @@
 		#if _MIPS_SIM == _MIPS_SIM_ABI64	/* n64 */
 			#define __NR_gettid 5178
 		#endif
+	#elif defined __loongarch64
+		#define __NR_gettid 178
 	#else
-		#define -1
 		#warning "__NR_gettid not defined for your architecture"
 	#endif
 #endif
@@ -494,8 +504,9 @@
 		#if _MIPS_SIM == _MIPS_SIM_ABI64	/* n64 */
 			#define __NR_execveat 5316
 		#endif
+	#elif defined __loongarch64
+		#define __NR_execveat 281
 	#else
-		#define -1
 		#warning "__NR_execveat not defined for your architecture"
 	#endif
 #endif
@@ -733,8 +744,9 @@
 		#if _MIPS_SIM == _MIPS_SIM_ABI64	/* n64 */
 			#define __NR_personality (132 + 5000)
 		#endif
+	#elif defined __loongarch64
+		#define __NR_personality 92
 	#else
-		#define -1
 		#warning "__NR_personality not defined for your architecture"
 	#endif
 #endif
