@@ -1,8 +1,7 @@
 /* SPDX-License-Identifier: LGPL-2.1+ */
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE 1
-#endif
+#include "config.h"
+
 #include <errno.h>
 #include <libgen.h>
 #include <stdio.h>
@@ -14,11 +13,10 @@
 #include <sys/wait.h>
 #include <unistd.h>
 
-#include <lxc/lxccontainer.h>
+#include "lxc.h"
 
 #include "arguments.h"
 #include "caps.h"
-#include "config.h"
 #include "confile.h"
 #include "log.h"
 #include "utils.h"
@@ -130,7 +128,8 @@ static bool set_argv(struct lxc_container *c, struct lxc_arguments *args)
 	return true;
 }
 
-int main(int argc, char *argv[])
+int __attribute__((weak, alias("lxc_execute_main"))) main(int argc, char *argv[]);
+int lxc_execute_main(int argc, char *argv[])
 {
 	struct lxc_container *c;
 	struct lxc_log log;
