@@ -1,19 +1,7 @@
 /* liblxcapi
  *
- * Copyright © 2017 Christian Brauner <christian.brauner@ubuntu.com>.
+ * SPDX-License-Identifier: GPL-2.0-only
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2, as
- * published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -288,7 +276,7 @@ int main(int argc, char *argv[])
 
 		lxc_debug("Starting namespace sharing test iteration %d\n", j);
 
-		for (i = 0; i < nthreads; i++) {
+		for (i = 0; (size_t)i < nthreads; i++) {
 			memset(&args[i], 0, sizeof(struct thread_args));
 			memset(&threads[i], 0, sizeof(pthread_t));
 
@@ -303,7 +291,7 @@ int main(int argc, char *argv[])
 				goto on_error_stop;
 		}
 
-		for (i = 0; i < nthreads; i++) {
+		for (i = 0; (size_t)i < nthreads; i++) {
 			ret = pthread_join(threads[i], NULL);
 			if (ret != 0)
 				goto on_error_stop;
